<?php $TRANSLATIONS = array(
"Pictures" => "ピクチャ",
"Shared by" => "共有者：",
"Share" => "共有",
"The \"Image Viewer\" application also need to be enabled to use this application." => "このアプリケーションを利用するためには、\"画像ビューア\" も有効化する必要があります。"
);
